==> 0.0.13.tar.gz: lib/utilities/constants.dart <==
import 'package:flutter/material.dart';
import 'colors.dart';

final headerTextStyle =
    TextStyle(color: Colors.black, fontSize: 18, fontWeight: FontWeight.w500);
final appThemeData = ThemeData(
  appBarTheme: AppBarTheme(elevation: 0.0),
  accentColor: kOrangeMaterialColor.shade50,
  backgroundColor: kOrangeColor,
  cardColor: Colors.white,
  splashColor: kOrangeMaterialColor.shade200,
  highlightColor: kOrangeMaterialColor.shade100,
  textSelectionTheme: TextSelectionThemeData(
    cursorColor: Colors.grey,
    selectionColor: kOrangeColor.withOpacity(0.4),
    selectionHandleColor: kOrangeColor.withOpacity(0.05),
  ),
);

final kInputEnabledBorder = UnderlineInputBorder(
  borderSide: BorderSide(color: kOrangeColorWithOpacity),
);

final kLabelStyle = TextStyle(
  color: kOrangeColorWithOpacity,
  fontFamily: 'OpenSans',
);

final kInputContentPadding = EdgeInsets.only(bottom: 14.0, top: 28.0);

final kInputBorder = UnderlineInputBorder(
  borderSide: BorderSide(color: Color.fromRGBO(96, 61, 153, 0.16), width: 2.0),
);

final kGreyBorder = UnderlineInputBorder(
  borderSide: BorderSide(color: Colors.grey.withOpacity(0.5), width: 1.0),
);

final kInputTextStyle = TextStyle(color: Colors.black, fontFamily: '');

final kWhiteContainerDecoration = BoxDecoration(
  color: Colors.white,
  borderRadius: BorderRadius.only(
      topLeft: Radius.circular(24), topRight: Radius.circular(24)),
);

final kWhiteRoundedContainer = BoxDecoration(
  color: Colors.white,
  borderRadius: BorderRadius.all(Radius.circular(16)),
);

final kTopContainerPadding = EdgeInsets.fromLTRB(20.0, 100.0, 20.0, 20.0);

final kWhiteContainerPadding = EdgeInsets.fromLTRB(20.0, 10.0, 20.0, 30.0);

final kContainerGradient = Container(
  height: double.infinity,
  width: double.infinity,
  decoration: BoxDecoration(
    gradient: LinearGradient(
      begin: Alignment.topLeft,
      end: Alignment.bottomRight,
      colors: [
        Color(0xFFFCA64F),
        Color(0xFFFCA64F),
      ],
    ),
  ),
);

final kContainerGradientWithShapes = Container(
  height: double.infinity,
  width: double.infinity,
  decoration: BoxDecoration(
    image: DecorationImage(
      alignment: Alignment.topCenter,
      fit: BoxFit.contain,
      image: AssetImage(
        'assets/background-shapes.png',
      ),
    ),
    gradient: LinearGradient(
      begin: Alignment.topLeft,
      end: Alignment.bottomRight,
      colors: [
        Color(0xFFFCA64F),
        Color(0xFFFCA64F),
      ],
    ),
  ),
);

final kHeaderStyle = TextStyle(color: Colors.deepPurple[900], fontSize: 18);

final kSimpleTextStyle = TextStyle(color: Colors.black, fontSize: 14);
final kSimpleTextStyle16 = TextStyle(color: Colors.black, fontSize: 16);
final kSimpleTextStyle18 = TextStyle(color: Colors.black, fontSize: 18);
final kBiggerBoldTextStyle =
    TextStyle(color: Colors.black, fontSize: 18, fontWeight: FontWeight.bold);
final kSimpleBoldTextStyle =
    TextStyle(color: Colors.black, fontSize: 16, fontWeight: FontWeight.bold);
final kSimpleLittleSmallerBoldTextStyle =
    TextStyle(color: Colors.black, fontSize: 14, fontWeight: FontWeight.bold);

final kPalePurpleContainerDecoration = BoxDecoration(
    borderRadius: BorderRadius.circular(8),
    color: Color.fromRGBO(106, 27, 154, 0.08));
final kPalePurpleFaqContainerDecoration = BoxDecoration(
    borderRadius: BorderRadius.circular(36),
    color: Color.fromRGBO(106, 27, 154, 0.08));
final kPaleIconColor = Color.fromRGBO(106, 27, 154, 0.32);

final kLinkTextStyle = TextStyle(color: Colors.deepPurple, fontSize: 18);

final kPurpleButtonColor = Colors.deepPurple[600];
final kPurpleButtonShape = RoundedRectangleBorder(
  borderRadius: BorderRadius.circular(30.0),
);
final kPurpleButtonPadding =
    EdgeInsets.symmetric(horizontal: 100, vertical: 14);
final kPurpleButtonTextStyle = TextStyle(
  color: Colors.white,
  fontSize: 18,
);

final kOutlinedButtonBorder = RoundedRectangleBorder(
  borderRadius: BorderRadius.circular(30.0),
  side: BorderSide(color: kOrangeMaterialColor),
);

final kYellowFlatButtonColor = Colors.orange[50];
final kYellowSelectedFlatButtonColor = Colors.orange[100];
final kYellowFlatButtonSplashColor = Colors.orange[200];
final kYellowFlatButtonTextColor = Colors.orange;
final kYellowFlatButtonShape =
    RoundedRectangleBorder(borderRadius: BorderRadius.circular(20.0));
final kYellowFlatButtonPadding =
    EdgeInsets.symmetric(horizontal: 12, vertical: 6);
final kYellowButtonTextStyle = TextStyle(
    color: kYellowFlatButtonTextColor,
    fontSize: 16,
    fontWeight: FontWeight.normal);

final greyInputTextStyle = TextStyle(
    color: Colors.white,
    fontFamily: 'Rubik',
    fontWeight: FontWeight.w400,
    fontSize: 16);

final whiteInputTextStyle = TextStyle(
    color: appDarkBlueColor,
    fontFamily: 'Rubik',
    fontWeight: FontWeight.w400,
    fontSize: 16);

final orangeButtonTextStyle = TextStyle(
    color: Colors.white,
    fontFamily: 'Rubik',
    fontWeight: FontWeight.w500,
    fontSize: 16);

final appBarTextStyle = TextStyle(
    fontWeight: FontWeight.w500,
    fontSize: 20,
    color: Colors.white,
    fontFamily: 'Rubik');

final greyInputContentPadding = EdgeInsets.only(left: 16);

final orangeButtonShape = RoundedRectangleBorder(
  borderRadius: BorderRadius.circular(6.0),
);

final greyInputLabelStyle = TextStyle(
  color: appGreyTextColor,
  fontFamily: 'Rubik',
  fontWeight: FontWeight.normal,
);

final whiteInputLabelStyle = TextStyle(
  color: appDarkGreyTextColor,
  fontFamily: 'Rubik',
  fontWeight: FontWeight.normal,
);

final greyInputHintStyle = TextStyle(
  color: Colors.white,
  fontFamily: 'Rubik',
);

==> 0.1.90.tar.gz: lib/utilities/constants.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_screenutil/flutter_screenutil.dart';
import 'colors.dart';

final headerTextStyle = TextStyle(
    color: Colors.black,
    fontSize: ScreenUtil().setSp(18),
    fontWeight: FontWeight.w500);
final appThemeData = ThemeData(
  appBarTheme: AppBarTheme(elevation: 0.0),
  accentColor: secondColor,
  backgroundColor: secondColor,
  cardColor: Colors.white,
  splashColor: secondColor,
  highlightColor: secondColor,
  textSelectionTheme: TextSelectionThemeData(
    cursorColor: Colors.grey,
    selectionColor: secondColor.withOpacity(0.4),
    selectionHandleColor: secondColor.withOpacity(0.05),
  ),
);

final kInputEnabledBorder = UnderlineInputBorder(
  borderSide: BorderSide(color: secondColor),
);

final kLabelStyle = TextStyle(
  color: secondColor,
  fontFamily: 'OpenSans',
);

final kInputContentPadding = EdgeInsets.only(bottom: 14.0, top: 28.0);

final kInputBorder = UnderlineInputBorder(
  borderSide: BorderSide(color: Color.fromRGBO(96, 61, 153, 0.16), width: 2.0),
);

final kGreyBorder = UnderlineInputBorder(
  borderSide: BorderSide(color: Colors.grey.withOpacity(0.5), width: 1.0),
);

final kInputTextStyle = TextStyle(color: Colors.black, fontFamily: '');

final kWhiteContainerDecoration = BoxDecoration(
  color: Colors.white,
  borderRadius: BorderRadius.only(
      topLeft: Radius.circular(24), topRight: Radius.circular(24)),
);

final kWhiteRoundedContainer = BoxDecoration(
  color: Colors.white,
  borderRadius: BorderRadius.all(Radius.circular(16)),
);

final kTopContainerPadding = EdgeInsets.fromLTRB(20.0, 100.0, 20.0, 20.0);

final kWhiteContainerPadding = EdgeInsets.fromLTRB(20.0, 10.0, 20.0, 30.0);

final kContainerGradient = Container(
  height: double.infinity,
  width: double.infinity,
  decoration: BoxDecoration(
    gradient: LinearGradient(
      begin: Alignment.topLeft,
      end: Alignment.bottomRight,
      colors: [
        secondColor,
        secondColor,
      ],
    ),
  ),
);

final kContainerGradientWithShapes = Container(
  height: double.infinity,
  width: double.infinity,
  decoration: BoxDecoration(
    image: DecorationImage(
      alignment: Alignment.topCenter,
      fit: BoxFit.contain,
      image: AssetImage(
        'assets/background-shapes.png',
      ),
    ),
    gradient: LinearGradient(
      begin: Alignment.topLeft,
      end: Alignment.bottomRight,
      colors: [
        secondColor,
        secondColor,
      ],
    ),
  ),
);

final kHeaderStyle = TextStyle(
  color: Colors.deepPurple[900],
  fontSize: ScreenUtil().setSp(18),
);

final kSimpleTextStyle = TextStyle(
  color: Colors.black,
  fontSize: ScreenUtil().setSp(14),
);
final kSimpleTextStyle16 = TextStyle(
  color: Colors.black,
  fontSize: ScreenUtil().setSp(16),
);
final kSimpleTextStyle18 = TextStyle(
  color: Colors.black,
  fontSize: ScreenUtil().setSp(18),
);
final kBiggerBoldTextStyle = TextStyle(
    color: Colors.black,
    fontSize: ScreenUtil().setSp(18),
    fontWeight: FontWeight.bold);
final kSimpleBoldTextStyle = TextStyle(
    color: Colors.black,
    fontSize: ScreenUtil().setSp(16),
    fontWeight: FontWeight.bold);
final kSimpleLittleSmallerBoldTextStyle = TextStyle(
    color: Colors.black,
    fontSize: ScreenUtil().setSp(14),
    fontWeight: FontWeight.bold);

final kPalePurpleContainerDecoration = BoxDecoration(
    borderRadius: BorderRadius.circular(8),
    color: Color.fromRGBO(106, 27, 154, 0.08));
final kPalePurpleFaqContainerDecoration = BoxDecoration(
    borderRadius: BorderRadius.circular(36),
    color: Color.fromRGBO(106, 27, 154, 0.08));
final kPaleIconColor = Color.fromRGBO(106, 27, 154, 0.32);

final kLinkTextStyle = TextStyle(
  color: Colors.deepPurple,
  fontSize: ScreenUtil().setSp(18),
);

final kPurpleButtonColor = Colors.deepPurple[600];
final kPurpleButtonShape = RoundedRectangleBorder(
  borderRadius: BorderRadius.circular(30.0),
);
final kPurpleButtonPadding =
    EdgeInsets.symmetric(horizontal: 100, vertical: 14);
final kPurpleButtonTextStyle = TextStyle(
  color: Colors.white,
  fontSize: ScreenUtil().setSp(18),
);

final kOutlinedButtonBorder = RoundedRectangleBorder(
  borderRadius: BorderRadius.circular(30.0),
  side: BorderSide(color: secondColor),
);

final kYellowFlatButtonShape =
    RoundedRectangleBorder(borderRadius: BorderRadius.circular(20.0));
final kYellowFlatButtonPadding =
    EdgeInsets.symmetric(horizontal: 12, vertical: 6);

final greyInputTextStyle = TextStyle(
  color: Colors.white,
  fontFamily: 'Rubik',
  fontWeight: FontWeight.w400,
  fontSize: ScreenUtil().setSp(16),
);

final whiteInputTextStyle = TextStyle(
  color: appDarkBlueColor,
  fontFamily: 'Rubik',
  fontWeight: FontWeight.w400,
  fontSize: ScreenUtil().setSp(16),
);

final orangeButtonTextStyle = TextStyle(
  color: Colors.white,
  fontFamily: 'Rubik',
  fontWeight: FontWeight.w500,
  fontSize: ScreenUtil().setSp(16),
);

final appBarTextStyle = TextStyle(
    fontWeight: FontWeight.w500,
    fontSize: ScreenUtil().setSp(20),
    color: Colors.white,
    fontFamily: 'Rubik');

final greyInputContentPadding = EdgeInsets.only(left: 16);

final orangeButtonShape = RoundedRectangleBorder(
  borderRadius: BorderRadius.circular(6.0),
);

final greyInputLabelStyle = TextStyle(
  color: appGreyTextColor,
  fontFamily: 'Rubik',
  fontWeight: FontWeight.normal,
);

final whiteInputLabelStyle = TextStyle(
  color: appDarkGreyTextColor,
  fontFamily: 'Rubik',
  fontWeight: FontWeight.normal,
);

final greyInputHintStyle = TextStyle(
  color: Colors.white,
  fontFamily: 'Rubik',
);

const String BASE_LOG_NAME = 'phonedo.feed.app.';
